@@ -2282,7 +2282,7 @@ impl<I: Tokens> Parser<I> {
 
             if is!(p, "class") {
                 return p
-                    .parse_class_decl(start, start, decorators)
+                    .parse_class_decl(start, start, decorators, false)
                     .map(|decl| match decl {
                         Decl::Class(c) => Decl::Class(ClassDecl {
                             declare: true,
@@ -2394,19 +2394,7 @@ impl<I: Tokens> Parser<I> {
                     if next {
                         bump!(self);
                     }
-                    let mut decl = self.parse_class_decl(start, start, decorators)?;
-                    match decl {
-                        Decl::Class(ClassDecl {
-                            class:
-                                Class {
-                                    ref mut is_abstract,
-                                    ..
-                                },
-                            ..
-                        }) => *is_abstract = true,
-                        _ => unreachable!(),
-                    }
-                    return Ok(Some(decl));
+                    return Ok(Some(self.parse_class_decl(start, start, decorators, true)?));
                 }
             }
 
